@@ -3,7 +3,7 @@ use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.047';
+$VERSION = '2.048';
 
 use Mail::Box::FastScalar;
 
@@ -46,14 +46,18 @@ sub read($@)
                      : 1;
 
     require Mail::Box::Parser::Perl;  # not parseable by C parser
+
     my $parser = Mail::Box::Parser::Perl->new
-     ( filename  => $filename
+     ( %args
+     , filename  => $filename
      , file      => $file
      , trusted   => 1
      );
 
     my $self = $class->new(%args);
     $self->readFromParser($parser);
+    $self->addReport($parser);
+
     $parser->stop;
 
     my $head = $self->head;
