@@ -3,7 +3,7 @@ use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.047';
+$VERSION = '2.048';
 
 use Mail::Message::Body::Multipart;
 use Mail::Address;
@@ -30,8 +30,8 @@ sub reply(@)
         unless(defined $body)
         {   # text attachment
             $body = $self->body;
-            $body = $body->part(0) if $body->isMultipart && $body->parts==1;
-            $body = $body->nested  if $body->isNested;
+            $body = $body->part(0)->body if $body->isMultipart && $body->parts==1;
+            $body = $body->nested->body  if $body->isNested;
 
             $body
              = $strip && ! $body->isMultipart && !$body->isBinary
