@@ -3,7 +3,7 @@ use strict;
 
 package Mail::Message::Head::Partial;
 use vars '$VERSION';
-$VERSION = '2.047';
+$VERSION = '2.048';
 use base 'Mail::Message::Head::Complete';
 
 use Scalar::Util 'weaken';
@@ -50,11 +50,12 @@ sub removeFieldsExcept(@)
 sub removeResentGroups()
 {   my $self = shift;
     require Mail::Message::Head::ResentGroup;
-    
+
     my $known = $self->{MMH_fields};
     my $found = 0;
     foreach my $name (keys %$known)
-    {   next if $name !~ $Mail::Message::Head::ResentGroup::resent_field_names;
+    {   next unless Mail::Message::Head::ResentGroup
+                         ->isResentGroupFieldName($name);
         delete $known->{$name};
         $found++;
     }
@@ -74,7 +75,27 @@ sub removeListGroup()
     my $known = $self->{MMH_fields};
     my $found = 0;
     foreach my $name (keys %$known)
-    {   next unless $name =~ $Mail::Message::Head::ListGroup::list_field_names;
+    {   next unless Mail::Message::Head::ListGroup->isListGroupFieldName($name);
+        delete $known->{$name};
+	$found++;
+    }
+
+    $self->cleanupOrderedFields if $found;
+    $self->modified(1) if $found;
+    $found;
+}
+
+#------------------------------------------
+
+
+sub removeSpamGroups()
+{   my $self = shift;
+    require Mail::Message::Head::SpamGroup;
+
+    my $known = $self->{MMH_fields};
+    my $found = 0;
+    foreach my $name (keys %$known)
+    {   next unless Mail::Message::Head::SpamGroup->isSpamGroupFieldName($name);
         delete $known->{$name};
 	$found++;
     }
