@@ -3,24 +3,24 @@ use warnings;
 
 package Mail::Message::Wrapper::SpamAssassin;
 use vars '$VERSION';
-$VERSION = '2.047';
+$VERSION = '2.048';
 use base 'Mail::SpamAssassin::Message';
 
 use Carp;
-use Mail::Message::Body::Lines;
+use Mail::Message::Body;
 
 #------------------------------------------
 
 
-sub new(@)
+sub new(@)    # fix missing infra-structure of base element
 {   my ($class, $message, %args) = @_;
+
+    $_->delete for $message->head->spamGroups('SpamAssassin');
+
     $class->SUPER::new($message)->init(\%args);
 }
 
-sub init($)
-{   my ($self, $args) = @_;
-    $self;
-}
+sub init($) { shift }
 
 #------------------------------------------
 
@@ -38,11 +38,21 @@ sub get_header($)
 
 #------------------------------------------
 
+sub get_pristine_header($)
+{   my ($self, $name) = @_;
+    my $field = $self->get_mail_object->head->get($name);
+    defined $field ? $field->foldedBody : undef;
+}
+
+#------------------------------------------
+
 sub put_header($$)
 {   my ($self, $name, $value) = @_;
     my $head = $self->get_mail_object->head;
     $value =~ s/\s{2,}/ /g;
-    return if $value =~ s/^\s*$//;
+    $value =~ s/\s*$//;      # will cause a refold as well
+    return () unless length $value;
+
     $head->add($name => $value);
 }
 
@@ -75,12 +85,21 @@ sub get_body() {shift->get_mail_object->body->lines }
 
 #------------------------------------------
 
+sub get_pristine() { shift->get_mail_object->head->string }
+
+#------------------------------------------
+
 sub replace_body($)
 {   my ($self, $data) = @_;
-    my $body = Mail::Message::Body::Lines->new(data => $data);
+    my $body = Mail::Message::Body->new(data => $data);
     $self->get_mail_object->storeBody($body);
 }
 
 #------------------------------------------
 
+sub replace_original_message($)
+{   my ($self, $lines) = @_;
+    die "We will not replace the message.  Use report_safe = 0\n";
+}
+
 1;
